@@ -2,7 +2,7 @@
 from django.apps import apps
 from django.contrib import admin
 from django.utils.timezone import localtime
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from cap.decorators import template_list_item
 
