@@ -1,5 +1,6 @@
 
 from django import forms
+from django.utils.translation import gettext_lazy as _
 
 from orders.models import Order
 
@@ -15,6 +16,13 @@ class CheckoutForm(forms.ModelForm):
 
         self.fields['delivery'].init_form(*args, **kwargs)
 
+    def clean_mobile(self):
+        mobile = self.cleaned_data['mobile']
+        if mobile.startswith('+3800'):
+            raise forms.ValidationError(
+                _('Phone number could not start with `+3800`'))
+        return mobile
+
     class Meta:
         model = Order
         fields = [
