@@ -1,11 +1,9 @@
 
 from django.apps import apps
 from django.conf import settings
-from django.contrib import messages
 from django.template.loader import render_to_string
 from django.contrib.sites.models import Site
 from django.core.mail import mail_managers
-from django.utils.safestring import mark_safe
 from django.utils.translation import gettext_lazy as _
 
 
@@ -39,19 +37,9 @@ def send_new_order_email(context, subject=None):
     mail_managers(subject=subject, message='', html_message=html)
 
 
-def push_new_order_message_to_session(request, context):
-
-    message = render_to_string('orders/new_order_message.html', context)
-
-    messages.success(request, mark_safe(message))
-
-
 def send_new_order_notifications(request, order):
 
     context = get_new_order_context(order)
 
     send_new_order_email(context)
     send_new_order_sms(context)
-
-    if not order.is_liqpay_payment():
-        push_new_order_message_to_session(request, context)
